@@ -1,4 +1,4 @@
-from typing import Dict, Optional
+from typing import Optional
 from urllib.parse import urlunsplit, urljoin
 
 
@@ -9,6 +9,7 @@ class UrlBuilder:
         'avax': ('snowtrace.io', 'AVAX'),
         'polygon': ('polygonscan.com', 'MATIC'),
         'optimism': ('etherscan.io', 'ETH'),
+        'base': ('basescan.org', 'ETH'),
         'arbitrum': ('arbiscan.io', 'ETH'),
         'fantom': ('ftmscan.com', 'FTM'),
     }
@@ -28,9 +29,11 @@ class UrlBuilder:
     def _set_api_kind(self, api_kind: str) -> None:
         api_kind = api_kind.lower().strip()
         if api_kind not in self._API_KINDS:
-            raise ValueError(f'Incorrect api_kind {api_kind!r}, supported only: {", ".join(self._API_KINDS)}')
+            raise ValueError(
+                f'Incorrect api_kind {api_kind!r}, supported only: {", ".join(self._API_KINDS)}'
+            )
         else:
-            self._api_kind = api_kind
+            self.api_kind = api_kind
 
     @property
     def _is_main(self) -> bool:
@@ -38,12 +41,12 @@ class UrlBuilder:
 
     @property
     def _base_netloc(self) -> str:
-        netloc, _ = self._API_KINDS[self._api_kind]
+        netloc, _ = self._API_KINDS[self.api_kind]
         return netloc
 
     @property
     def currency(self) -> str:
-        _, currency = self._API_KINDS[self._api_kind]
+        _, currency = self._API_KINDS[self.api_kind]
         return currency
 
     def get_link(self, path: str) -> str:
@@ -59,36 +62,32 @@ class UrlBuilder:
             ('optimism', False): f'api-{self._network}-optimistic',
         }
         default_prefix = 'api' if self._is_main else f'api-{self._network}'
-        prefix = prefix_exceptions.get((self._api_kind, self._is_main), default_prefix)
+        prefix = prefix_exceptions.get((self.api_kind, self._is_main), default_prefix)
 
         return self._build_url(prefix, 'api')
 
     def _get_base_url(self) -> str:
-        network_exceptions = {
-            ('polygon', 'testnet'): 'mumbai'
-        }
-        network = network_exceptions.get((self._api_kind, self._network), self._network)
+        network_exceptions = {('polygon', 'testnet'): 'mumbai'}
+        network = network_exceptions.get((self.api_kind, self._network), self._network)
 
         prefix_exceptions = {
             ('optimism', True): 'optimistic',
             ('optimism', False): f'{network}-optimism',
         }
         default_prefix = None if self._is_main else network
-        prefix = prefix_exceptions.get((self._api_kind, self._is_main), default_prefix)
+        prefix = prefix_exceptions.get((self.api_kind, self._is_main), default_prefix)
 
         return self._build_url(prefix)
 
-    def filter_and_sign(self, params: Dict):
-        return self._sign(
-            self._filter_params(params or {})
-        )
+    def filter_and_sign(self, params: dict):
+        return self._sign(self._filter_params(params or {}))
 
-    def _sign(self, params: Dict) -> Dict:
+    def _sign(self, params: dict) -> dict:
         if not params:
             params = {}
         params['apikey'] = self._API_KEY
         return params
 
     @staticmethod
-    def _filter_params(params: Dict) -> Dict:
+    def _filter_params(params: dict) -> dict:
         return {k: v for k, v in params.items() if v is not None}
